Commit 843b7377e9ffedb0d814ad403d3ca3a8ccbf558f

ckolivas 2014-01-28T10:25:25

Relax timeout in hf get header to 500ms to match the usb timeout.

diff --git a/driver-hashfast.c b/driver-hashfast.c
index 3c27872..366709a 100644
--- a/driver-hashfast.c
+++ b/driver-hashfast.c
@@ -188,7 +188,7 @@ static bool hfa_get_header(struct cgpu_info *hashfast, struct hf_header *h, uint
 
 	orig_len = len = sizeof(*h);
 
 	/* Read for up to 200ms till we find the first occurrence of HF_PREAMBLE
 	 * though it should be the first byte unless we get woefully out of
 	 * sync. */
 	cgtimer_time(&ts_start);
@@ -197,7 +197,7 @@ static bool hfa_get_header(struct cgpu_info *hashfast, struct hf_header *h, uint
 
 		cgtimer_time(&ts_now);
 		cgtimer_sub(&ts_now, &ts_start, &ts_diff);
-		if (cgtimer_to_ms(&ts_diff) > 200)
+		if (cgtimer_to_ms(&ts_diff) > 500)
 			return false;
 
 		if (unlikely(hashfast->usbinfo.nodev))
@@ -188,7 +188,7 @@ static bool hfa_get_header(struct cgpu_info *hashfast, struct hf_header *h, uint
 	orig_len = len = sizeof(*h);
 
-	/* Read for up to 200ms till we find the first occurrence of HF_PREAMBLE
+	/* Read for up to 500ms till we find the first occurrence of HF_PREAMBLE
 	 * though it should be the first byte unless we get woefully out of
 	 * sync. */